#
# spec file for package python-msal-extensions
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%if 0%{?suse_version} >= 1500
%define skip_python2 1
%endif
Name:           python-msal-extensions
Version:        1.0.0
Release:        2.3
Summary:        Microsoft Authentication Library (MSAL) for Python Extensions
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/AzureAD/microsoft-authentication-library-for-python
Source:         https://files.pythonhosted.org/packages/source/m/msal-extensions/msal-extensions-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-msal < 2.0.0
Requires:       python-msal >= 0.4.1
Requires:       python-portalocker < 3.0
Requires:       python-portalocker >= 1.0
%ifpython2
Requires:       python-pathlib2
Requires:       python-portalocker < 2.0
%endif
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module msal < 2.0.0}
BuildRequires:  %{python_module msal >= 0.4.1}
BuildRequires:  %{python_module portalocker < 3.0}
BuildRequires:  %{python_module portalocker >= 1.0}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
The Microsoft Authentication Library (MSAL) for Python library enables your app
to access the Microsoft Cloud by supporting authentication of users with Microsoft
Azure Active Directory accounts (AAD) and Microsoft Accounts (MSA) using industry
standard OAuth2 and OpenID Connect.

This packages contains additional extensions.

%prep
%setup -q -n msal-extensions-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc README.md
%{python_sitelib}/*

%changelog
* Mon May  8 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Relax version constraints for python-portalocker in BuildRequires and Requires
* Tue Apr 26 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.0.0
  + New: Add a new platform-independent build_encrypted_persistence() API. (#87, #110)
  + Remove: Old TokenCache API which has been deprecated for 2 years. (#110)
  + Enhancement: Make all platform-dependent parameters optional (#103)
  + Enhancement: Provide PersistenceEncryptError and PersistenceDecryptError,
    currently raised when encryption on Windows fails. (#108)
  + Enhancement: The data file will be created with 600 permission when
    running in Unix-like systems. (#107)
* Mon Jan  3 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.3.1
  + Enhancement: Better concurrency (#61, #63, #100)
  + Bugfix: Now supports user home dir in drive root on Windows (#83, #84)
  + Enhancement: This package can now be run inside container
  + Enhancement: Improvement compatibility with PyInstaller 3.5 on Python 2.7 (#85, #91)
  + Enhancement: Catchable exception when persistence is unavailable (#92, #93)
  + Enhancement: Support dependency portalocker 2.0+ (#94, #97)
  + Enhancement: Improve documentation (#77, #102)
  + Including license in release package (#76)
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Tue Sep  8 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.3.0
  + New unified PersistenceNotFound exception is now raised for cases
    where the persistence is not found. (#64, #67)
  + Bugfix: File not found exception is now handled for Python 2.7 as a no-op (#69)
  + Added performance tests for locking behavior (#58)
  + A non-exist persistence on Linux platform would previously return a None.
    Since this release, it will raise PersistenceNotFound exception which becomes
    a consistent behavior on Windows and macOS.
* Fri Aug 28 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.2.2
  + Bugfix: Restored compatibility with upstream package portalocker version
    < 1.4.0 when running on non-Windows platform (#50)
  + Bugfix: Cache on Windows was not functioning in version 0.2.0 and 0.2.1(#52)
  + Enhancement: Improved readme providing installation and usage instructions (#53)
- from version 0.2.1
  + Functionally the same as 0.2.0, but we change the installation-time and import-time
    dependency of PyGObject to run-time dependency. This would make the installation
    easier for those customers who do not necessarily need to use the Encryption on Linux. (#47)
  + The version 1.6.0+ of upstream package portalocker is only required on Windows.
    Other platforms remain with portalocker 1.0.0+. (#49)
- from version 0.2.0
  + New feature: Support token cache encryption when running on Linux Desktop (#4, #44)
  + Bug fix: The cache lock was not properly removed on Windows 10 (#42, #43)
  + Change: A new set of API PersistedTokenCache is provided. Previous API is now deprecated
    and will be removed in next major release which will likely come within a month:
    WindowsTokenCache, OSXTokenCache, UnencryptedTokenCache, FileTokenCache and TokenCache.
  + Since this release, we have a dependency on PyGObject, when running on Linux.
    You may need to follow its installation steps, or follow our CI setup.
- Update Requires from setup.py
* Tue Feb 18 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.1.3
